@@ -13,8 +13,8 @@ class AnnotationInstance(ClassifierInstance, ABC):
     """
 
     @abstractmethod
-    def get_annotation_definition(self) -> 'Annotation':
+    def get_annotation_definition(self) -> "Annotation":
         pass
 
-    def get_classifier(self) -> 'Annotation':
+    def get_classifier(self) -> "Annotation":
         return self.get_annotation_definition()
