@@ -2,6 +2,7 @@ from typing import TYPE_CHECKING, Dict, List, cast
 
 if TYPE_CHECKING:
     from lionwebpython.language.concept import Concept
+
 from lionwebpython.language.containment import Containment
 from lionwebpython.language.language import Language
 from lionwebpython.language.lioncore_builtins import LionCoreBuiltins
@@ -20,7 +21,7 @@ class LionCore:
     @classmethod
     def get_language_entity(
         cls, lion_web_version: LionWebVersion = LionWebVersion.current_version()
-    ) -> 'Concept':
+    ) -> "Concept":
         return cls.get_instance(lion_web_version).require_concept_by_name(
             "LanguageEntity"
         )
@@ -28,25 +29,25 @@ class LionCore:
     @classmethod
     def get_link(
         cls, lion_web_version: LionWebVersion = LionWebVersion.current_version()
-    ) -> 'Concept':
+    ) -> "Concept":
         return cls.get_instance(lion_web_version).require_concept_by_name("Link")
 
     @classmethod
     def get_classifier(
         cls, lion_web_version: LionWebVersion = LionWebVersion.current_version()
-    ) -> 'Concept':
+    ) -> "Concept":
         return cls.get_instance(lion_web_version).require_concept_by_name("Classifier")
 
     @classmethod
     def get_feature(
         cls, lion_web_version: LionWebVersion = LionWebVersion.current_version()
-    ) -> 'Concept':
+    ) -> "Concept":
         return cls.get_instance(lion_web_version).require_concept_by_name("Feature")
 
     @classmethod
     def get_structured_data_type(
         cls, lion_web_version: LionWebVersion = LionWebVersion.current_version()
-    ) -> 'Concept':
+    ) -> "Concept":
         return cls.get_instance(lion_web_version).require_concept_by_name(
             "StructuredDataType"
         )
@@ -54,63 +55,65 @@ class LionCore:
     @classmethod
     def get_field(
         cls, lion_web_version: LionWebVersion = LionWebVersion.current_version()
-    ) -> 'Concept':
+    ) -> "Concept":
         return cls.get_instance(lion_web_version).require_concept_by_name("Field")
 
     @classmethod
     def get_annotation(
         cls, lion_web_version: LionWebVersion = LionWebVersion.current_version()
-    ) -> 'Concept':
+    ) -> "Concept":
         return cls.get_instance(lion_web_version).require_concept_by_name("Annotation")
 
     @classmethod
     def get_concept(
         cls, lion_web_version: LionWebVersion = LionWebVersion.current_version()
-    ) -> 'Concept':
+    ) -> "Concept":
         if not isinstance(lion_web_version, LionWebVersion):
-            raise ValueError(f"Expected lion_web_version to be an instance of LionWebVersion but got {lion_web_version}")
+            raise ValueError(
+                f"Expected lion_web_version to be an instance of LionWebVersion but got {lion_web_version}"
+            )
         return cls.get_instance(lion_web_version).require_concept_by_name("Concept")
 
     @classmethod
     def get_interface(
         cls, lion_web_version: LionWebVersion = LionWebVersion.current_version()
-    ) -> 'Concept':
+    ) -> "Concept":
         return cls.get_instance(lion_web_version).require_concept_by_name("Interface")
 
     @classmethod
     def get_containment(
         cls, lion_web_version: LionWebVersion = LionWebVersion.current_version()
-    ) -> 'Concept':
+    ) -> "Concept":
         return cls.get_instance(lion_web_version).require_concept_by_name("Containment")
 
     @classmethod
     def get_data_type(
         cls, lion_web_version: LionWebVersion = LionWebVersion.current_version()
-    ) -> 'Concept':
+    ) -> "Concept":
         return cls.get_instance(lion_web_version).require_concept_by_name("DataType")
 
     @classmethod
     def get_enumeration(
         cls, lion_web_version: LionWebVersion = LionWebVersion.current_version()
-    ) -> 'Concept':
+    ) -> "Concept":
         return cls.get_instance(lion_web_version).require_concept_by_name("Enumeration")
 
     @classmethod
     def get_language(
         cls, lion_web_version: LionWebVersion = LionWebVersion.current_version()
-    ) -> 'Concept':
+    ) -> "Concept":
         return cls.get_instance(lion_web_version).require_concept_by_name("Language")
 
     @classmethod
     def get_reference(
         cls, lion_web_version: LionWebVersion = LionWebVersion.current_version()
-    ) -> 'Concept':
+    ) -> "Concept":
         return cls.get_instance(lion_web_version).require_concept_by_name("Reference")
 
     @classmethod
     def get_property(
         cls, lion_web_version: LionWebVersion = LionWebVersion.current_version()
-    ) -> 'Concept':
+    ) -> "Concept":
         return cls.get_instance(lion_web_version).require_concept_by_name("Property")
 
     @classmethod
@@ -136,7 +139,9 @@ class LionCore:
         from lionwebpython.language.concept import Concept
 
         if not isinstance(lion_web_version, LionWebVersion):
-            raise ValueError(f"Expected lion_web_version to be an instance of LionWebVersion but got {lion_web_version}")
+            raise ValueError(
+                f"Expected lion_web_version to be an instance of LionWebVersion but got {lion_web_version}"
+            )
         if lion_web_version not in cls._instances:
             version_id_suffix = (
                 f"-{IdUtils.clean_string(lion_web_version.value)}"
