@@ -1,4 +1,4 @@
-from typing import Dict, List, TYPE_CHECKING
+from typing import TYPE_CHECKING, Dict, List
 
 from lionwebpython.language.data_type import DataType
 from lionwebpython.lionweb_version import LionWebVersion
@@ -31,6 +31,7 @@ from lionwebpython.serialization.unavailable_node_policy import \
 if TYPE_CHECKING:
     from lionwebpython.model.annotation_instance import AnnotationInstance
 
+
 class AbstractSerialization:
 
     DEFAULT_SERIALIZATION_FORMAT = LionWebVersion.current_version()
@@ -40,6 +41,7 @@ class AbstractSerialization:
     ):
         from lionwebpython.api.local_classifier_instance_resolver import \
             LocalClassifierInstanceResolver
+
         self.lion_web_version = lionweb_version
         self.classifier_resolver = ClassifierResolver()
         self.instantiator = Instantiator()
@@ -158,7 +160,7 @@ class AbstractSerialization:
         return serialized_instance
 
     def serialize_annotation_instance(
-        self, annotation_instance: 'AnnotationInstance'
+        self, annotation_instance: "AnnotationInstance"
     ) -> SerializedClassifierInstance:
         if annotation_instance is None:
             raise ValueError("AnnotationInstance should not be null")
@@ -298,7 +300,8 @@ class AbstractSerialization:
             CompositeClassifierInstanceResolver
         from lionwebpython.model.annotation_instance import AnnotationInstance
         from lionwebpython.model.impl.proxy_node import ProxyNode
-        from lionwebpython.serialization.map_based_resolver import MapBasedResolver
+        from lionwebpython.serialization.map_based_resolver import \
+            MapBasedResolver
         from lionwebpython.serialization.node_populator import NodePopulator
 
         if lion_web_version is None:
